@@ -63,6 +63,16 @@ def AddArgNetworkFirewallPolicyCreation(parser):
   )
 
 
+def AddPolicyType(parser):
+  """Adds policy type argument."""
+  parser.add_argument(
+      '--policy-type',
+      required=False,
+      choices=['VPC_POLICY', 'RDMA_ROCE_POLICY'],
+      help='Network firewall policy type.',
+  )
+
+
 def AddArgsUpdateNetworkFirewallPolicy(parser):
   """Adds the arguments  for firewall policy update."""
   parser.add_argument(
@@ -87,7 +97,11 @@ def NetworkFirewallPolicyAssociationArgument(
   )
 
 
-def AddArgsCreateAssociation(parser, support_priority=False):
+def AddArgsCreateAssociation(
+    parser,
+    support_priority=False,
+    support_associated_policy_to_be_replaced=False,
+):
   """Adds the arguments of association creation."""
   parser.add_argument('--name', help='Name of the association.')
 
@@ -105,7 +119,17 @@ def AddArgsCreateAssociation(parser, support_priority=False):
         help='Priority of the association.',
     )
 
-  parser.add_argument(
+  group = parser
+  if support_associated_policy_to_be_replaced:
+    group = parser.add_group(mutex=True, required=False)
+    group.add_argument(
+        '--associated-policy-to-be-replaced',
+        required=False,
+        hidden=True,
+        help='Name of an already associated firewall policy to replace.',
+    )
+
+  group.add_argument(
       '--replace-association-on-target',
       action='store_true',
       default=False,
@@ -480,7 +504,7 @@ def AddSrcRegionCodes(parser, support_network_scopes=False):
   if support_network_scopes:
     help_text += (
         ' Cannot be specified when the source network'
-        ' scope is NON_INTERNET, VPC_NETWORK or INTRA_VPC.'
+        ' type is NON_INTERNET, VPC_NETWORK or INTRA_VPC.'
     )
   parser.add_argument(
       '--src-region-codes',
@@ -674,3 +698,34 @@ def AddDestNetworkType(parser, required=False):
           ' empty string to clear the field.'
       ),
   )
+
+
+def AddTargetType(parser, required=False):
+  """Adds target type to this rule."""
+  parser.add_argument(
+      '--target-type',
+      required=required,
+      choices=['INSTANCES', 'INTERNAL_MANAGED_LB'],
+      help=(
+          'Target type of the rule. By default a rule applies to VM instances'
+          ' (target-type = INSTANCES). Use INTERNAL_MANAGED_LB value to apply'
+          ' the rule to load balancers.'
+      ),
+  )
+
+
+def AddTargetForwardingRules(parser, required=False):
+  """Adds target forwarding rules to this rule."""
+  parser.add_argument(
+      '--target-forwarding-rules',
+      required=required,
+      type=arg_parsers.ArgList(),
+      metavar='TARGET_FORWARDING_RULES',
+      help=(
+          'A list of forwarding rules to which this rule applies. This field'
+          ' allows you to control which load balancers get this rule. If not'
+          ' specified, the rule applies to all load balancers. This field is'
+          ' only applicable when --target-type is INTERNAL_MANAGED_LB. It'
+          ' accepts full or partial resourceURLs.'
+      ),
+  )
