@@ -22,7 +22,7 @@ from googlecloudsdk.calliope import base
 
 def AddTypeFlag(parser):
   """Adds a --type flag to the given parser."""
-  help_text = """Type can be MYSQL, ORACLE, POSTGRESQL, GOOGLE-CLOUD-STORAGE or BIGQUERY"""
+  help_text = """Type can be MYSQL, ORACLE, POSTGRESQL, SQLSERVER, SALESFORCE, GOOGLE-CLOUD-STORAGE or BIGQUERY"""
 
   parser.add_argument('--type', help=help_text, required=True)
 
@@ -439,6 +439,12 @@ def AddMongodbProfileGroup(parser, required=True):
       action='store_true',
       default=False,
   )
+  ssl_config = mongodb_profile.add_group()
+  ssl_config.add_argument(
+      '--mongodb-tls',
+      help="""Enable Transport Layer Security for the monogodb connection.""",
+      action='store_true',
+      default=False)
 
 
 def AddDepthGroup(parser):
