@@ -169,29 +169,6 @@ def ExecutionDependencies():
   return {_STARTED: {_RESOURCES_AVAILABLE}, _COMPLETED: {_STARTED}}
 
 
-# TODO(b/322180315): Once Worker's API is ready,
-# replace Service/Configuration related references.
-def WorkerStages(
-    include_build=False,
-    include_create_repo=False,
-    include_create_revision=True,
-):
-  """Return the progress tracker Stages for conditions of a Worker."""
-  stages = []
-  if include_create_repo:
-    stages.append(_CreateRepoStage())
-  if include_build:
-    stages.append(_UploadSourceStage())
-    stages.append(_BuildContainerStage())
-  if include_create_revision:
-    stages.append(
-        progress_tracker.Stage(
-            'Creating Revision...', key=SERVICE_CONFIGURATIONS_READY
-        )
-    )
-  return stages
-
-
 def WorkerPoolStages(
     include_build=False,
     include_create_repo=False,
