@@ -36,12 +36,15 @@ from .content import (
     ModalityTokenCount,
     Part,
     PrebuiltVoiceConfig,
+    ProactivityConfig,
     RetrievalMetadata,
     SafetyRating,
     SafetySetting,
     SearchEntryPoint,
     Segment,
     SpeechConfig,
+    UrlContextMetadata,
+    UrlMetadata,
     VideoMetadata,
     VoiceConfig,
     HarmCategory,
@@ -140,6 +143,7 @@ from .tool import (
     Tool,
     ToolConfig,
     ToolUseExample,
+    UrlContext,
     VertexAISearch,
     VertexRagStore,
 )
@@ -160,6 +164,7 @@ from .vertex_rag_data import (
     RagEngineConfig,
     RagFile,
     RagFileChunkingConfig,
+    RagFileMetadataConfig,
     RagFileParsingConfig,
     RagFileTransformationConfig,
     RagManagedDbConfig,
@@ -187,12 +192,15 @@ __all__ = (
     'ModalityTokenCount',
     'Part',
     'PrebuiltVoiceConfig',
+    'ProactivityConfig',
     'RetrievalMetadata',
     'SafetyRating',
     'SafetySetting',
     'SearchEntryPoint',
     'Segment',
     'SpeechConfig',
+    'UrlContextMetadata',
+    'UrlMetadata',
     'VideoMetadata',
     'VoiceConfig',
     'HarmCategory',
@@ -277,6 +285,7 @@ __all__ = (
     'Tool',
     'ToolConfig',
     'ToolUseExample',
+    'UrlContext',
     'VertexAISearch',
     'VertexRagStore',
     'BoolArray',
@@ -293,6 +302,7 @@ __all__ = (
     'RagEngineConfig',
     'RagFile',
     'RagFileChunkingConfig',
+    'RagFileMetadataConfig',
     'RagFileParsingConfig',
     'RagFileTransformationConfig',
     'RagManagedDbConfig',
